@@ -3,29 +3,30 @@
 
 #include <sys/cdefs.h>
 #include <sys/types.h>
+#include <endian.h>
 
-#if defined(__i386__) || defined(__x86_64__)
+#if defined(__i386__)
 struct stat {
-	unsigned short st_dev;
-	unsigned short __pad1;
-	unsigned long st_ino;
-	unsigned short st_mode;
-	unsigned short st_nlink;
-	unsigned short st_uid;
-	unsigned short st_gid;
-	unsigned short st_rdev;
-	unsigned short __pad2;
-	unsigned long  st_size;
-	unsigned long  st_blksize;
-	unsigned long  st_blocks;
-	  signed long  st_atime;
-	unsigned long  __unused1;
-	  signed long  st_mtime;
-	unsigned long  __unused2;
-	  signed long  st_ctime;
-	unsigned long  __unused3;
-	unsigned long  __unused4;
-	unsigned long  __unused5;
+	unsigned short	st_dev;
+	unsigned short	__pad1;
+	unsigned long	st_ino;
+	unsigned short	st_mode;
+	unsigned short	st_nlink;
+	unsigned short	st_uid;
+	unsigned short	st_gid;
+	unsigned short	st_rdev;
+	unsigned short	__pad2;
+	unsigned long	st_size;
+	unsigned long	st_blksize;
+	unsigned long	st_blocks;
+	  signed long	st_atime;
+	unsigned long	__unused1;
+	  signed long	st_mtime;
+	unsigned long	__unused2;
+	  signed long	st_ctime;
+	unsigned long	__unused3;
+	unsigned long	__unused4;
+	unsigned long	__unused5;
 };
 
 struct stat64 {
@@ -170,14 +171,14 @@ struct stat {
 struct stat64 {
 	unsigned long	st_dev;
 	unsigned long	st_pad0[3];	/* Reserved for st_dev expansion  */
-	ino_t		st_ino;
-	mode_t		st_mode;
-	nlink_t		st_nlink;
-	uid_t		st_uid;
-	gid_t		st_gid;
+__extension__ unsigned long long	st_ino;
+	unsigned int	st_mode;
+	unsigned int	st_nlink;
+	unsigned int	st_uid;
+	unsigned int	st_gid;
 	unsigned long	st_rdev;
 	unsigned long	st_pad1[3];	/* Reserved for st_rdev expansion  */
-__extension__	long long	st_size;
+__extension__ long long	st_size;
 	/*
 	 * Actually this should be timestruc_t st_atime, st_mtime and st_ctime
 	 * but we don't have it under Linux.
@@ -189,7 +190,8 @@ __extension__	long long	st_size;
 	time_t		st_ctime;
 	unsigned long	reserved2;	/* Reserved for st_atime expansion  */
 	unsigned long	st_blksize;
-__extension__	long long	st_blocks;
+	unsigned long	st_pad2;
+__extension__ long long	st_blocks;
 };
 #elif defined(__powerpc__)
 struct stat {
@@ -197,20 +199,20 @@ struct stat {
 	ino_t		st_ino;
 	mode_t		st_mode;
 	nlink_t		st_nlink;
-	uid_t 		st_uid;
-	gid_t 		st_gid;
+	uid_t		st_uid;
+	gid_t		st_gid;
 	dev_t		st_rdev;
 	off_t		st_size;
-	unsigned long  	st_blksize;
-	unsigned long  	st_blocks;
-	  signed long  	st_atime;
-	unsigned long  	__unused1;
-	  signed long  	st_mtime;
-	unsigned long  	__unused2;
-	  signed long  	st_ctime;
-	unsigned long  	__unused3;
-	unsigned long  	__unused4;
-	unsigned long  	__unused5;
+	unsigned long	st_blksize;
+	unsigned long	st_blocks;
+	  signed long	st_atime;
+	unsigned long	__unused1;
+	  signed long	st_mtime;
+	unsigned long	__unused2;
+	  signed long	st_ctime;
+	unsigned long	__unused3;
+	unsigned long	__unused4;
+	unsigned long	__unused5;
 };
 
 /* This matches struct stat64 in glibc2.1.
@@ -239,26 +241,26 @@ __extension__	long long st_blocks;		/* Number 512-byte blocks allocated. */
 };
 #elif defined(__arm__)
 struct stat {
-	unsigned short st_dev;
-	unsigned short __pad1;
-	unsigned long st_ino;
-	unsigned short st_mode;
-	unsigned short st_nlink;
-	unsigned short st_uid;
-	unsigned short st_gid;
-	unsigned short st_rdev;
-	unsigned short __pad2;
-	unsigned long  st_size;
-	unsigned long  st_blksize;
-	unsigned long  st_blocks;
-	  signed long  st_atime;
-	unsigned long  __unused1;
-	  signed long  st_mtime;
-	unsigned long  __unused2;
-	  signed long  st_ctime;
-	unsigned long  __unused3;
-	unsigned long  __unused4;
-	unsigned long  __unused5;
+	unsigned short	st_dev;
+	unsigned short	__pad1;
+	unsigned long	st_ino;
+	unsigned short	st_mode;
+	unsigned short	st_nlink;
+	unsigned short	st_uid;
+	unsigned short	st_gid;
+	unsigned short	st_rdev;
+	unsigned short	__pad2;
+	unsigned long	st_size;
+	unsigned long	st_blksize;
+	unsigned long	st_blocks;
+	  signed long	st_atime;
+	unsigned long	__unused1;
+	  signed long	st_mtime;
+	unsigned long	__unused2;
+	  signed long	st_ctime;
+	unsigned long	__unused3;
+	unsigned long	__unused4;
+	unsigned long	__unused5;
 };
 
 /* This matches struct stat64 in glibc2.1, hence the absolutely
@@ -298,32 +300,32 @@ __extension__	unsigned long long	st_ino;
 };
 #elif defined(__s390__)
 struct stat {
-	unsigned short st_dev;
-	unsigned short __pad1;
-	unsigned long  st_ino;
-	unsigned short st_mode;
-	unsigned short st_nlink;
-	unsigned short st_uid;
-	unsigned short st_gid;
-	unsigned short st_rdev;
-	unsigned short __pad2;
-	unsigned long  st_size;
-	unsigned long  st_blksize;
-	unsigned long  st_blocks;
-	unsigned long  st_atime;
-	unsigned long  __unused1;
-	unsigned long  st_mtime;
-	unsigned long  __unused2;
-	unsigned long  st_ctime;
-	unsigned long  __unused3;
-	unsigned long  __unused4;
-	unsigned long  __unused5;
+	unsigned short	st_dev;
+	unsigned short	__pad1;
+	unsigned long	st_ino;
+	unsigned short	st_mode;
+	unsigned short	st_nlink;
+	unsigned short	st_uid;
+	unsigned short	st_gid;
+	unsigned short	st_rdev;
+	unsigned short	__pad2;
+	unsigned long	st_size;
+	unsigned long	st_blksize;
+	unsigned long	st_blocks;
+	unsigned long	st_atime;
+	unsigned long	__unused1;
+	unsigned long	st_mtime;
+	unsigned long	__unused2;
+	unsigned long	st_ctime;
+	unsigned long	__unused3;
+	unsigned long	__unused4;
+	unsigned long	__unused5;
 };
 struct stat64 {
 	unsigned char	__pad0[6];
 	unsigned short	st_dev;
 	unsigned int	__pad1;
-#define STAT64_HAS_BROKEN_ST_INO        1
+#define STAT64_HAS_BROKEN_ST_INO	1
 	unsigned long	__st_ino;
 	unsigned int	st_mode;
 	unsigned int	st_nlink;
@@ -373,6 +375,7 @@ struct stat {
 struct stat64 {
 	unsigned long long st_dev;
 	unsigned int __pad1;
+#define STAT64_HAS_BROKEN_ST_INO	1
 	unsigned long __st_ino;
 	unsigned long st_mode;
 	unsigned long st_nlink;
@@ -393,27 +396,49 @@ struct stat64 {
 	unsigned long long st_ino;
 };
 
+#elif defined(__x86_64__)
+struct stat {
+	unsigned long	st_dev;
+	unsigned long	st_ino;
+	unsigned long	st_nlink;
+	unsigned int	st_mode;
+	unsigned int	st_uid;
+	unsigned int	st_gid;
+	unsigned int	__pad0;
+	unsigned long	 st_rdev;
+	unsigned long	st_size;
+	unsigned long	st_blksize;
+	unsigned long	st_blocks;
+	unsigned long	st_atime;
+	unsigned long	__reserved0;
+	unsigned long	st_mtime;
+	unsigned long	__reserved1;
+	unsigned long	st_ctime;
+	unsigned long	__reserved2;
+	long		__unused[3];
+};
+
 #elif defined(__ia64__)
 
 struct stat {
-	unsigned long st_dev;
-	unsigned long st_ino;
-	unsigned long st_nlink;
-	unsigned int  st_mode;
-	unsigned int  st_uid;
-	unsigned int  st_gid;
-	unsigned int  __pad;
-	unsigned long st_rdev;
-	unsigned long st_size;
-	unsigned long st_atime;
-	unsigned long reserved;
-	unsigned long st_mtime;
-	unsigned long reserved2;
-	unsigned long st_ctime;
-	unsigned long reserved3;
-	unsigned long st_blksize;
-	long          st_blocks;
-	unsigned long pad[3];
+	unsigned long	st_dev;
+	unsigned long	st_ino;
+	unsigned long	st_nlink;
+	unsigned int	st_mode;
+	unsigned int	st_uid;
+	unsigned int	st_gid;
+	unsigned int	__pad;
+	unsigned long	st_rdev;
+	unsigned long	st_size;
+	unsigned long	st_atime;
+	unsigned long	reserved;
+	unsigned long	st_mtime;
+	unsigned long	reserved2;
+	unsigned long	st_ctime;
+	unsigned long	reserved3;
+	unsigned long	st_blksize;
+	long		st_blocks;
+	unsigned long	pad[3];
 };
 
 #endif
@@ -453,21 +478,16 @@ struct stat {
 #define S_IWOTH 00002
 #define S_IXOTH 00001
 
-#ifndef STAT64_HAS_BROKEN_ST_INO
-#define __NO_STAT64
-#endif
-
 extern int stat(const char *__file, struct stat *__buf) __THROW;
 extern int fstat(int __fd, struct stat *__buf) __THROW;
 extern int lstat(const char *__file, struct stat *__buf) __THROW;
 
-#ifdef __NO_STAT64
-#undef _FILE_OFFSET_BITS
+#if __WORDSIZE == 64
+#define __NO_STAT64
 #else
 extern int stat64(const char *__file, struct stat64 *__buf) __THROW;
 extern int fstat64(int __fd, struct stat64 *__buf) __THROW;
 extern int lstat64(const char *__file, struct stat64 *__buf) __THROW;
-#endif
 
 #if defined _FILE_OFFSET_BITS && _FILE_OFFSET_BITS == 64
 #define lstat lstat64
@@ -476,6 +496,7 @@ extern int lstat64(const char *__file, struct stat64 *__buf) __THROW;
 #define pread pread64
 #define pwrite pwrite64
 #endif
+#endif
 
 #define major(dev) (((dev)>>8) & 0xff)
 #define minor(dev) ((dev) & 0xff)
