@@ -17,12 +17,15 @@ int atexit(function t) {
 }
 
 extern void _exit(int code) __attribute__((noreturn));
+extern void __thread_doexit();
 
+void __libc_exit(int code);
 void __libc_exit(int code) {
   register int i=atexit_counter;
+  __thread_doexit();
   while(i) {
     __atexitlist[--i]();
   }
   _exit(code);
 }
-void exit(int code) __attribute__((weak,alias("__libc_exit")));
+void exit(int code) __attribute__((alias("__libc_exit")));
