@@ -25,10 +25,16 @@ int execvp(const char *file, char *const argv[]) {
     if (next==cur) {
       buf[0]='.';
       cur--;
-    } else
+    } else {
+      if (next-cur>=PATH_MAX-3) { error: errno=EINVAL; return -1; }
       memmove(buf,cur,(size_t)(next-cur));
+    }
     buf[next-cur]='/';
-    memmove(&buf[next-cur+1],file,strlen(file)+1);
+    {
+      int len=strlen(file);
+      if (len+(next-cur)>=PATH_MAX-2) goto error;
+      memmove(&buf[next-cur+1],file,strlen(file)+1);
+    }
     if (execve(buf,argv,environ)==-1) {
       if (errno==ENOEXEC)
 	return __exec_shell(buf,argv);
