@@ -1,6 +1,8 @@
 #include <unistd.h>
+#include <string.h>
 #include <fcntl.h>
 #include <errno.h>
+#include "dietfeatures.h"
 
 /*
  * by Olaf Dreesen
@@ -13,6 +15,8 @@
  * default	->	processor\t: <cpunr>\n	(one per cpu)
  */
 
+#ifdef SLASH_PROC_OK
+int __sc_nr_cpus(void);
 int __sc_nr_cpus() {
 #if defined(__arm__)
   return 1;
@@ -53,3 +57,8 @@ int __sc_nr_cpus() {
   }
 #endif
 }
+#else
+int __sc_nr_cpus() {
+  return 1;	/* kludge kludge ;-) */
+}
+#endif
